**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             modelEco_rotation2.gms
Sequence         2 - The farm model
Type             LP
GAMS language    SUBSET

Description
Source: INOSYS network of chambers of agriculture in the Centre Val de Loire region

An arable crop farmer growing special crops in the Centre-Val de Loire region has 110 ha of land.
Irrigation and the economic environment of his farm offer him a large range of production options:
soft wheat, durum wheat, spring barley, potatoes for human consumption, sugar beets and rapeseed.
Five of these crop types are irrigated in order to ensure high quality regular production.
The farmer has 60 000 m3 of water.
Irrigation needs and economic data are shown in the table below:

Irrigation
Crops                           Vol en m3/ha
Soft wheat                           175
Durum wheat                          350
Spring barley                        700
Potato for human consumption        1800
Sugar beet                          1750

Technico-economic data
Crops                          Yields  (qx/ha)           Prices/qx ()            Total costs (/ha)
Soft wheat                           85                      16                       460
Durum wheat                          71                      28                       565
Spring barley                        70                      17.5                     470
Potato for human consumption        495                      14                      4210
Sugar beet                          950                       2.6                    1082
Rapeseed                             40                      38                       490

For agronomic reasons,
 Oilseed crops cannot be grown more than once every three years on the same plot,
 cereal crops cannot be grown two years in a row on the same plot,
 and sugar beets or potatoes can only be cultivated once every six years.

3 rotations have been observed in the practices of the farmers :

sugar beet/Soft Wheat/Barley/Rapeseed/Soft Wheat/Durum Wheat
Rapeseed/Soft Wheat/Barley/Potato/Soft Wheat/Durum Wheat
Rapeseed/Soft Wheat/Barley/Rapeseed/Soft Wheat/Durum Wheat

"



$Offtext


*----------                         DECLARATIONS                    ----------*
sets
A activities      /rot1, rot2, rot3/
;

*----------                          DATA                        ----------*
scalar
LAND_A land availability in hectares               /110/
WATER_A   water availability                      /60000/
;

parameter Water_N(A) water needs per crop and technology (m3 per ha)
/rot1 525
 rot2 533.333
 rot3 233.333/
;

parameter
Gm(A)
/rot1  916
 rot2 1288
 rot3 1006.333
/
;

*----------                         MODEL                           ----------*
variables
Z     total farm income (euros)
;

positive variables
X    area per crop (hectares)
;

equations
   OBJECTIVE      objective function
   LAND           land equation
   WATER          irrigation equation
;

OBJECTIVE..        sum (A, Gm(A)* X(A)) =E= Z ;

LAND..             sum(A, X(A)) =l= LAND_A  ;

WATER..            sum(A, Water_N(A)*X(A)) =l= WATER_A  ;

model modelS2 first example /all/;

*----------                        SOLUTION                         ----------*
solve modelS2 using LP maximizing Z;





